@@ -37,7 +37,6 @@ rxode2_fn2 gammaqInv;
 rxode2_fn2 gammaqInva;
 
 rxode2i_fn2 rxnorm;
-rxode2i_fn2 rxnormV;
 rxode2i_rxbinom rxbinom;
 rxode2i_rxbinom rxnbinom;
 rxode2i_rxbinom rxnbinomMu;
@@ -54,7 +53,6 @@ rxode2i_fn2 rxunif;
 rxode2i_fn2 rxweibull;
 
 rxode2i2_fn2 rinorm;
-rxode2i2_fn2 rinormV;
 rxode2i2_ribinom ribinom;
 rxode2i2_ribinom rinbinom;
 rxode2i2_ribinom rinbinomMu;
@@ -266,41 +264,38 @@ void _assignFuns0(void) {
   linCmtB=(linCmtB_p)R_GetCCallable("rxode2parse", "linCmtB");
   linCmtC=(linCmtA_p)R_GetCCallable("rxode2parse", "linCmtC");
     
-  rxnorm = (rxode2i_fn2)R_GetCCallable("rxode2", "rxnorm");
-  rxnormV = (rxode2i_fn2)R_GetCCallable("rxode2", "rxnormV");
-  rxbinom = (rxode2i_rxbinom)R_GetCCallable("rxode2","rxbinom");
-  rxnbinom = (rxode2i_rxbinom)R_GetCCallable("rxode2","rxnbinom");
-  rxnbinomMu = (rxode2i_rxbinom)R_GetCCallable("rxode2","rxnbinomMu");
-  rxcauchy = (rxode2i_fn2)R_GetCCallable("rxode2","rxcauchy") ;
-  rxchisq = (rxode2i_fn)R_GetCCallable("rxode2","rxchisq") ;
-  rxexp = (rxode2i_fn)R_GetCCallable("rxode2","rxexp");
-  rxf = (rxode2i_fn2)R_GetCCallable("rxode2","rxf") ;
-  rxgeom = (rxode2i_ifn)R_GetCCallable("rxode2","rxgeom") ;
-  rxgamma = (rxode2i_fn2)R_GetCCallable("rxode2","rxgamma") ;
-  rxbeta = (rxode2i_fn2)R_GetCCallable("rxode2","rxbeta") ;
-  rxpois = (rxode2i_ifn)R_GetCCallable("rxode2","rxpois") ;
-  rxt_ = (rxode2i_fn)R_GetCCallable("rxode2","rxt_") ;
-  rxunif = (rxode2i_fn2)R_GetCCallable("rxode2","rxunif") ;
-  rxweibull = (rxode2i_fn2)R_GetCCallable("rxode2","rxweibull");
-
-  rinorm = (rxode2i2_fn2)R_GetCCallable("rxode2", "rinorm");
-  rinormV = (rxode2i2_fn2)R_GetCCallable("rxode2", "rinormV");
-  ribinom = (rxode2i2_ribinom)R_GetCCallable("rxode2","ribinom");
-  rinbinom = (rxode2i2_ribinom)R_GetCCallable("rxode2","rinbinom");
-  rinbinomMu = (rxode2i2_ribinom)R_GetCCallable("rxode2","rinbinomMu");
-  ricauchy = (rxode2i2_fn2)R_GetCCallable("rxode2","ricauchy") ;
-  richisq = (rxode2i2_fn)R_GetCCallable("rxode2","richisq") ;
-  riexp = (rxode2i2_fn)R_GetCCallable("rxode2","riexp");
-  rif = (rxode2i2_fn2)R_GetCCallable("rxode2","rif") ;
-  rigeom = (rxode2i2_ifn)R_GetCCallable("rxode2","rigeom") ;
-  rigamma = (rxode2i2_fn2)R_GetCCallable("rxode2","rigamma") ;
-  ribeta = (rxode2i2_fn2)R_GetCCallable("rxode2","ribeta") ;
-  ripois = (rxode2i2_ifn)R_GetCCallable("rxode2","ripois") ;
-  rit_ = (rxode2i2_fn)R_GetCCallable("rxode2","rit_") ;
-  riunif = (rxode2i2_fn2)R_GetCCallable("rxode2","riunif") ;
-  riweibull = (rxode2i2_fn2)R_GetCCallable("rxode2","riweibull");
-    
-  phi = (rxode2_fn)R_GetCCallable("rxode2","phi");
+  rxnorm = (rxode2i_fn2)R_GetCCallable("rxode2random", "rxnorm");
+  rxbinom = (rxode2i_rxbinom)R_GetCCallable("rxode2random","rxbinom");
+  rxnbinom = (rxode2i_rxbinom)R_GetCCallable("rxode2random","rxnbinom");
+  rxnbinomMu = (rxode2i_rxbinom)R_GetCCallable("rxode2random","rxnbinomMu");
+  rxcauchy = (rxode2i_fn2)R_GetCCallable("rxode2random","rxcauchy") ;
+  rxchisq = (rxode2i_fn)R_GetCCallable("rxode2random","rxchisq") ;
+  rxexp = (rxode2i_fn)R_GetCCallable("rxode2random","rxexp");
+  rxf = (rxode2i_fn2)R_GetCCallable("rxode2random","rxf");
+  rxgeom = (rxode2i_ifn)R_GetCCallable("rxode2random","rxgeom");
+  rxgamma = (rxode2i_fn2)R_GetCCallable("rxode2random","rxgamma");
+  rxbeta = (rxode2i_fn2)R_GetCCallable("rxode2random","rxbeta");
+  rxpois = (rxode2i_ifn)R_GetCCallable("rxode2random","rxpois");
+  rxt_ = (rxode2i_fn)R_GetCCallable("rxode2random","rxt_");
+  rxunif = (rxode2i_fn2)R_GetCCallable("rxode2random","rxunif");
+  rxweibull = (rxode2i_fn2)R_GetCCallable("rxode2random","rxweibull");
+  rinorm = (rxode2i2_fn2)R_GetCCallable("rxode2random", "rinorm");
+  ribinom = (rxode2i2_ribinom)R_GetCCallable("rxode2random","ribinom");
+  rinbinom = (rxode2i2_ribinom)R_GetCCallable("rxode2random","rinbinom");
+  rinbinomMu = (rxode2i2_ribinom)R_GetCCallable("rxode2random","rinbinomMu");
+  ricauchy = (rxode2i2_fn2)R_GetCCallable("rxode2random","ricauchy");
+  richisq = (rxode2i2_fn)R_GetCCallable("rxode2random","richisq");
+  riexp = (rxode2i2_fn)R_GetCCallable("rxode2random","riexp");
+  rif = (rxode2i2_fn2)R_GetCCallable("rxode2random","rif");
+  rigeom = (rxode2i2_ifn)R_GetCCallable("rxode2random","rigeom");
+  rigamma = (rxode2i2_fn2)R_GetCCallable("rxode2random","rigamma");
+  ribeta = (rxode2i2_fn2)R_GetCCallable("rxode2random","ribeta");
+  ripois = (rxode2i2_ifn)R_GetCCallable("rxode2random","ripois");
+  rit_ = (rxode2i2_fn)R_GetCCallable("rxode2random","rit_");
+  riunif = (rxode2i2_fn2)R_GetCCallable("rxode2random","riunif");
+  riweibull = (rxode2i2_fn2)R_GetCCallable("rxode2random","riweibull");
+  phi = (rxode2_fn)R_GetCCallable("rxode2random","phi");
+  
   gammap = (rxode2_fn2) R_GetCCallable("rxode2","gammap");
   gammaq = (rxode2_fn2) R_GetCCallable("rxode2","gammaq");
   gammapInv = (rxode2_fn2) R_GetCCallable("rxode2","gammapInv");
@@ -312,8 +307,8 @@ void _assignFuns0(void) {
   gammapDer  = (rxode2_fn2) R_GetCCallable("rxode2","gammapDer");
   logit = (rxode2_fn3) R_GetCCallable("rxode2", "logit");
   expit = (rxode2_fn3) R_GetCCallable("rxode2", "expit");
-  simeta =(_simfun) R_GetCCallable("rxode2", "simeta");
-  simeps =(_simfun) R_GetCCallable("rxode2", "simeps");
+  simeta =(_simfun) R_GetCCallable("rxode2random", "simeta");
+  simeps =(_simfun) R_GetCCallable("rxode2random", "simeps");
   
   _llikNorm=(rxode2_llikNormFun) R_GetCCallable("rxode2ll","rxLlikNorm");
   _llikNormDmean=(rxode2_llikNormFun) R_GetCCallable("rxode2ll","rxLlikNormDmean");
