@@ -65,7 +65,6 @@ sAppendN(&sbOut, "rxode2_fn2 gammapInva;\n", 23);
 sAppendN(&sbOut, "rxode2_fn2 gammaqInv;\n", 22);
 sAppendN(&sbOut, "rxode2_fn2 gammaqInva;\n", 23);
 sAppendN(&sbOut, "rxode2i_fn2 rxnorm;\n", 20);
-sAppendN(&sbOut, "rxode2i_fn2 rxnormV;\n", 21);
 sAppendN(&sbOut, "rxode2i_rxbinom rxbinom;\n", 25);
 sAppendN(&sbOut, "rxode2i_rxbinom rxnbinom;\n", 26);
 sAppendN(&sbOut, "rxode2i_rxbinom rxnbinomMu;\n", 28);
@@ -81,7 +80,6 @@ sAppendN(&sbOut, "rxode2i_fn rxt_;\n", 17);
 sAppendN(&sbOut, "rxode2i_fn2 rxunif;\n", 20);
 sAppendN(&sbOut, "rxode2i_fn2 rxweibull;\n", 23);
 sAppendN(&sbOut, "rxode2i2_fn2 rinorm;\n", 21);
-sAppendN(&sbOut, "rxode2i2_fn2 rinormV;\n", 22);
 sAppendN(&sbOut, "rxode2i2_ribinom ribinom;\n", 26);
 sAppendN(&sbOut, "rxode2i2_ribinom rinbinom;\n", 27);
 sAppendN(&sbOut, "rxode2i2_ribinom rinbinomMu;\n", 29);
@@ -246,7 +244,7 @@ sAppendN(&sbOut, "  double tad = t-tlast;\n", 24);
 sAppendN(&sbOut, "  double podo = _solveData->subjects[id].curDoseS[cmt];\n", 56);
 sAppendN(&sbOut, "  return exp(_safe_log(podo)+lktr+n*(lktr+_safe_log(tad))-ktr*(tad)-lgamma1p(nd));\n", 83);
 sAppendN(&sbOut, "}\n", 2);
-sAppendN(&sbOut, "void _assignFuns0() {\n", 22);
+sAppendN(&sbOut, "void _assignFuns0(void) {\n", 26);
 sAppendN(&sbOut, "  _getRxSolve_ = (_getRxSolve_t) R_GetCCallable(\"rxode2\",\"getRxSolve_\");\n", 73);
 sAppendN(&sbOut, "  _assign_ptr=(rxode2_assign_ptr) R_GetCCallable(\"rxode2\",\"rxode2_assign_fn_pointers\");\n", 88);
 sAppendN(&sbOut, "  _rxRmModelLib=(_rxRmModelLibType) R_GetCCallable(\"rxode2\",\"rxRmModelLib\");\n", 77);
@@ -268,7 +266,7 @@ void writeBody2(void) {
 sAppendN(&sbOut, "  // dynamic stop\n", 18);
 sAppendN(&sbOut, "  _solveData = _getRxSolve_();\n", 31);
 sAppendN(&sbOut, "}\n", 2);
-sAppendN(&sbOut, "void _assignFuns() {\n", 21);
+sAppendN(&sbOut, "void _assignFuns(void) {\n", 25);
 sAppendN(&sbOut, "  if (_assign_ptr == NULL){\n", 28);
 sAppendN(&sbOut, "    _assignFuns0();\n", 20);
 sAppendN(&sbOut, "  }\n", 4);
